@@ -4,22 +4,22 @@
 # ibus-anthy - The Anthy engine for IBus
 #
 # Copyright (c) 2007-2008 Peng Huang <shawn.p.huang@gmail.com>
-# Copyright (c) 2010-2012 Takao Fujiwara <takao.fujiwara1@gmail.com>
-# Copyright (c) 2007-2012 Red Hat, Inc.
+# Copyright (c) 2010-2016 Takao Fujiwara <takao.fujiwara1@gmail.com>
+# Copyright (c) 2007-2016 Red Hat, Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2, or (at your option)
-# any later version.
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 import os
 from os import path
@@ -28,7 +28,16 @@ import getopt
 import locale
 import xml.dom.minidom
 
-from gi.repository import GObject
+from gi import require_version as gi_require_version
+gi_require_version('GLib', '2.0')
+gi_require_version('IBus', '1.0')
+
+from gi.repository import GLib
+
+# set_prgname before importing factory to show the name in warning
+# messages when import modules are failed. E.g. Gtk.
+GLib.set_prgname('ibus-engine-anthy')
+
 from gi.repository import IBus
 
 import _config as config
@@ -42,7 +51,7 @@ class IMApp:
                                           version='0.1.0',
                                           license='GPL',
                                           author='Peng Huang <shawn.p.huang@gmail.com>',
-                                          homepage='http://code.google.com/p/ibus/',
+                                          homepage='https://github.com/ibus/ibus/wiki',
                                           command_line=command_line,
                                           textdomain='ibus-anthy')
         engine = IBus.EngineDesc(name='anthy',
@@ -56,7 +65,7 @@ class IMApp:
                                  symbol=config.SYMBOL_CHAR,
                                  rank=99)
         self.__component.add_engine(engine)
-        self.__mainloop = GObject.MainLoop()
+        self.__mainloop = GLib.MainLoop()
         self.__bus = IBus.Bus()
         self.__bus.connect('disconnected', self.__bus_disconnected_cb)
         self.__factory = factory.EngineFactory(self.__bus)
@@ -104,8 +113,6 @@ def resync_engine_file():
             nodes = elements[0].childNodes
         if len(nodes) > 0:
             version_str = nodes[0].data
-        if type(version_str) == unicode:
-            version_str = str(version_str)
         if version_str != '':
             version_str = version_str.strip()
         return version_str
@@ -126,17 +133,17 @@ def print_xml():
             xml = f
             break
     if xml == None:
-        print >> sys.stderr, 'Not exist: %s' % system_config
+        print('Not exist: %s' % system_config, file=sys.stderr)
         return
     file = open(xml, 'r')
-    print file.read()
+    print(file.read())
     file.close()
 
 def print_help(out, v = 0):
-    print >> out, '-i, --ibus             executed by ibus.'
-    print >> out, '-h, --help             show this message.'
-    print >> out, '-d, --daemonize        daemonize ibus.'
-    print >> out, '-x, --xml              print engine xml.'
+    print('-i, --ibus             executed by ibus.', file=out)
+    print('-h, --help             show this message.', file=out)
+    print('-d, --daemonize        daemonize ibus.', file=out)
+    print('-x, --xml              print engine xml.', file=out)
     sys.exit(v)
 
 def main():
@@ -154,7 +161,7 @@ def main():
 
     try:
         opts, args = getopt.getopt(sys.argv[1:], shortopt, longopt)
-    except getopt.GetoptError, err:
+    except getopt.GetoptError as err:
         print_help(sys.stderr, 1)
 
     for o, a in opts:
@@ -167,7 +174,7 @@ def main():
         elif o in ('-x', '--xml'):
             xml = True
         else:
-            print >> sys.stderr, 'Unknown argument: %s' % o
+            print('Unknown argument: %s' % o, file=sys.stderr)
             print_help(sys.stderr, 1)
 
     if daemonize:
